@@ -7,6 +7,8 @@
 
 void usage() {
   STD_cout << "genmakefile: Generates a Makefile for ODIN methods" << STD_endl;
+  STD_cout << configInfo() << STD_endl;
+  STD_cout << STD_endl;
   STD_cout << "Usage: genmakefile [options] <method-label>" << STD_endl;
   STD_cout << "Options:" << STD_endl;
   STD_cout << "\t" << LogBase::get_usage() << STD_endl;
