@@ -83,12 +83,13 @@ void usage(const Protocol& prot) {
 
   STD_cout << "Extra options:" << STD_endl;
   STD_cout << "\t-mask <Binary mask file: voxels with zeroes are discarded>" << STD_endl;
-  STD_cout << "File read options:" << STD_endl;
+  STD_cout << "Protocol options (overrides parameters in input data):" << STD_endl;
   STD_cout << prot.get_cmdline_usage("\t");
+  STD_cout << "File read options (will be applied to input data before processing):" << STD_endl;
   STD_cout << ropts.get_cmdline_usage("\t");
-  STD_cout << "File write options:" << STD_endl;
+  STD_cout << "File write options (will be applied to output data after processing):" << STD_endl;
   STD_cout << wopts.get_cmdline_usage("\t");
-  STD_cout << "Filters applied to input file(s) and mask:" << STD_endl;
+  STD_cout << "Filters/processing applied to input file(s) and mask, applied in the order they appear on the command line:" << STD_endl;
   STD_cout << filter.get_cmdline_usage("\t");
   STD_cout << "Other options:" << STD_endl;
   STD_cout << "\t" << LogBase::get_usage() << STD_endl;
@@ -101,12 +102,12 @@ void usage(const Protocol& prot) {
 ////////////////////////////////////////////////////////////////////////////
 
 
-bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain) {
+bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain, ProgressMeter* progmeter) {
   Log<OdinData> odinlog("micalc","read_infile");
 
   Data<float,4> datain;
 
-  if(datain.autoread(filename,ropts,&prot)<0) return false;
+  if(datain.autoread(filename,ropts,&prot, progmeter)<0) return false;
   if(!filterchain.apply(prot,datain)) return false;
   data.resize(datain.shape());
 
@@ -206,6 +207,11 @@ int main(int argc, char* argv[]) {
   wopts.parse_cmdline_options(argc,argv);
   prot.parse_cmdline_options(argc,argv);
 
+
+  ProgressDisplayConsole display;
+  ProgressMeter progmeter(display);
+
+
   FilterChain filterchain(argc,argv);
 
 
@@ -221,7 +227,7 @@ int main(int argc, char* argv[]) {
   if(accumulate || stateval) FileIO::set_trace_status(false);
 
   if(binaryop && infile1=="" && infile2=="") {
-    ODINLOG(odinlog,errorLog) << "Specifiy at least one file" << STD_endl;
+    ODINLOG(odinlog,errorLog) << "Specify at least one file" << STD_endl;
     return -1;
   }
 
@@ -229,12 +235,14 @@ int main(int argc, char* argv[]) {
   Data<float,4> data2;
 
   if(infile1!="") {
-    if(!read_infile(infile1, data1, ropts, prot, filterchain)) return -1;
+    if(!read_infile(infile1, data1, ropts, prot, filterchain,&progmeter)) return -1;
   }
 
   if(binaryop && infile2!="") {
-    Protocol protcopy(prot); // dispensable, protocol of first file will be used
-    if(!read_infile(infile2, data2, ropts, protcopy, filterchain)) return -1;
+    Protocol protcopy(prot); // dispensable protocol
+    Protocol* prot2p=&protcopy;
+    if(infile1=="") prot2p=&prot; // use only if 1st operand is number
+    if(!read_infile(infile2, data2, ropts, *prot2p, filterchain,&progmeter)) return -1;
   }
 
   TinyVector<int,4> outshape;
@@ -261,7 +269,7 @@ int main(int argc, char* argv[]) {
       data1=innumber1;
     }
     if(!has_shape1 && !has_shape2) {
-      ODINLOG(odinlog,errorLog) << "Specifiy at least one valid file" << STD_endl;
+      ODINLOG(odinlog,errorLog) << "Specify at least one valid file" << STD_endl;
       return -1;
     }
 
@@ -273,7 +281,7 @@ int main(int argc, char* argv[]) {
   if(maskfile!="") {
     Data<float,4> inmaskdata;
     Protocol maskprot;
-    if(!read_infile(maskfile, inmaskdata, ropts, maskprot, filterchain)) return -1;
+    if(!read_infile(maskfile, inmaskdata, ropts, maskprot, filterchain,&progmeter)) return -1;
 //    if(inmaskdata.autoread(maskfile,ropts)<0) return -1;
     if( inmaskdata.extent(0) && same_shape(data1, inmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
       maskdata.resize(data1.shape());
