@@ -33,7 +33,14 @@ int main(int argc, char *argv[]) {
   }
 
   GuiApplication a(argc, argv);  // debug handler will be initialized here
+
+  Log<MiViewComp> odinlog("","main");
+
   MiView* miview=new MiView();
+  ODINLOG(odinlog,normalDebug) << "MiView() done" << STD_endl;
+
   miview->set_caption((STD_string("MiView - ") + lastarg + parstring).c_str());
+  ODINLOG(odinlog,normalDebug) << "set_caption(...) done" << STD_endl;
+
   return a.start(miview->get_widget());
 }
