@@ -2,7 +2,7 @@
                           miviewview.h  -  description
                              -------------------
     begin                : Thu Jun 20 19:02:26 CEST 2002
-    copyright            : (C) 2000-2019 by Thies H. Jochimsen
+    copyright            : (C) 2000-2021 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -28,6 +28,7 @@
 
 // miview modules
 #include "miview_fmri.h"
+#include "miview_rois.h"
 
 
 class Protocol; // forward declaration
@@ -82,6 +83,7 @@ class MiViewView : public QWidget {
   bool is_image_display() const {return (get_nx()*get_ny())>1;}
   bool has_timecourse() const {return get_nrep()>1;}
   bool has_fmri() const {return fmri.is_valid();}
+  bool has_rois() const {return rois.is_valid();}
   bool has_overlay() const {return has_olm;}
 
  signals:
@@ -157,6 +159,7 @@ class MiViewView : public QWidget {
   LDRwidget* settingswidget;
   LDRwidget* tcoursewidget;
   LDRwidget* fmriwidget;
+  LDRwidget* roiswidget;
 
   STD_string data_fname_cache;
   STD_string image_fname_cache;
@@ -170,6 +173,7 @@ class MiViewView : public QWidget {
 
   // miview modules
   MiViewFmri fmri;
+  MiViewRois rois;
 
 
 };
