@@ -590,96 +590,6 @@ static const char *kspaceIcon[] = {
 
 
 
-
-static const char *visIcon[] = {
-/* columns rows colors chars-per-pixel */
-"22 22 59 1",
-"  c black",
-". c #020202",
-"X c #040404",
-"o c gray3",
-"O c #090909",
-"+ c gray4",
-"@ c #0C0C0C",
-"# c gray5",
-"$ c gray7",
-"% c #151515",
-"& c #161616",
-"* c #1B1B1B",
-"= c #1E1E1E",
-"- c gray12",
-"; c #222222",
-": c gray14",
-"> c #282828",
-", c gray16",
-"< c #2D2D2D",
-"1 c #313131",
-"2 c #323232",
-"3 c #373737",
-"4 c #393939",
-"5 c #3A3A3A",
-"6 c gray23",
-"7 c gray24",
-"8 c #3F3F3F",
-"9 c #414141",
-"0 c #444444",
-"q c #484848",
-"w c #5D5D5D",
-"e c #606060",
-"r c gray43",
-"t c gray44",
-"y c #747474",
-"u c gray48",
-"i c #838383",
-"p c gray52",
-"a c #868686",
-"s c #888888",
-"d c gray54",
-"f c #8E8E8E",
-"g c #909090",
-"h c #929292",
-"j c #989898",
-"k c #9A9A9A",
-"l c #A5A5A5",
-"z c gray68",
-"x c #AFAFAF",
-"c c #B7B7B7",
-"v c #C1C1C1",
-"b c gray77",
-"n c #C5C5C5",
-"m c gray78",
-"M c gainsboro",
-"N c gray88",
-"B c #E4E4E4",
-"V c #EFEFEF",
-"C c None",
-/* pixels */
-"CCCCCCCCCCCCCCCCCCCCCC",
-"CCCCCCCCCCCCCCCCCCCCCC",
-"CCCCCC11CCCCCCCCCCCCCC",
-"CCCCCC1w CCCCCCCCCCCCC",
-"CCCCCC1bw CCCCCCCCCCCC",
-"CCCCCC1bBw CCCCCCCCCCC",
-"CCCCCC<cVMw CCCCCCCCCC",
-"CCCCCC,xNcMw CCCCCCCCC",
-"CCCCCC:xbkfMw CCCCCCCC",
-"CCCCCC=lmkafMw CCCCCCC",
-"CCCCCC=kxpiphbw CCCCCC",
-"CCCCCC%hkiifxy4 CCCCCC",
-"CCCCCC$pkifxy4 CCCCCCC",
-"CCCCCC@uafxy4 CCCCCCCC",
-"CCCCCCOukxy4 CCCCCCCCC",
-"CCCCCC yky4 CCCCCCCCCC",
-"CCCCCC yy4 CCCCCCCCCCC",
-"CCCCCC r4 CCCCCCCCCCCC",
-"CCCCCC 8 CCCCCCCCCCCCC",
-"CCCCCC  CCCCCCCCCCCCCC",
-"CCCCCCCCCCCCCCCCCCCCCC",
-"CCCCCCCCCCCCCCCCCCCCCC"
-};
-
-
-
 static const char *simIcon[] = {
 /* columns rows colors chars-per-pixel */
 "22 22 79 1",
