@@ -860,7 +860,7 @@ void IdeaDialog::do_compile() {
   STD_string target="rebuild";
   if(opts_cache.make_clean) target+="-clean";
   if(!execute_make(make,target)) return;
-  msg=justificate("Congratulations! You have sucessfully compiled ODIN for IDEA. Includes and libraries have been installed under "+opts_cache.odindir);
+  msg=justificate("Congratulations! You have successfully compiled ODIN for IDEA. Includes and libraries have been installed under "+opts_cache.odindir);
   message_question(msg.c_str(), "Build complete", GuiDialog::get_widget());
 
   if(!execute_make(make,"ideaseq")) return;
@@ -1122,7 +1122,7 @@ void IdeaMethodDialog::make() {
     bool status=(!waitstate);
     ODINLOG(odinlog,normalDebug) << "status / waitstate = " << status << " / " << waitstate << STD_endl;
     if(!status && waitstate!=-2) {
-      message_question("An error occured during method compilation", "Make Failed", GuiDialog::get_widget(),false,true);
+      message_question("An error occurred during method compilation", "Make Failed", GuiDialog::get_widget(),false,true);
       this->emitDone();
       return;
     }
