@@ -2,15 +2,15 @@
 
 #include "odincomp.h"
 
-#include <odinpara/jdxblock.h>
+#include <odinpara/ldrblock.h>
 
-NewMethDialog::NewMethDialog(QWidget *parent, JcampDxBlock& files)
+NewMethDialog::NewMethDialog(QWidget *parent, LDRblock& files)
  : GuiDialog(parent,"Please select a template and a name for the new method",true) {
   Log<OdinComp> odinlog("NewMethDialog","NewMethDialog");
 
   grid=new GuiGridLayout(GuiDialog::get_widget(), 2, 2);
 
-  fileswidget=new JDXwidget(files,1,GuiDialog::get_widget());
+  fileswidget=new LDRwidget(files,1,GuiDialog::get_widget());
   connect(fileswidget,SIGNAL(valueChanged()),this,SLOT(emit_valueChanged()));
   grid->add_widget( fileswidget, 0, 0, GuiGridLayout::Default, 1, 2 );
 
