@@ -1,8 +1,19 @@
-#include "odinplot_vtk.h"
-#include "odincomp.h"
+#include <tjutils/config.h>
 
 #ifdef VTKSUPPORT
 
+
+// for early vtk 6 versions ?
+//#define vtkRenderingCore_AUTOINIT 1(vtkRenderingOpenGL)
+
+// please see https://vtk.org/Wiki/VTK/VTK_6_Migration/Factories_now_require_defines
+#ifdef VTKOPENGLMODULE
+#include <vtkAutoInit.h>
+#ifdef VTK_MODULE_INIT
+VTK_MODULE_INIT(VTKOPENGLMODULE);
+#endif
+#endif
+
 #include <vtkActor.h>
 #include <vtkCamera.h>
 #include <vtkMath.h>
@@ -20,6 +31,10 @@
 #endif
 
 
+#include "odinplot_vtk.h"
+#include "odincomp.h"
+
+
 VtkMagnPlotter::VtkMagnPlotter() {
 
 
