@@ -453,7 +453,7 @@ void OdinView::seqprops() {
   msg+="Number of Acquisitions : " + itos(method->get_numof_acquisitions()) + "\n";
   msg+="RF Energy Deposition : "+ftos(method->get_rf_energy())+" a.u.\n";
 
-  message_question(msg.c_str(), "Sequence Properies", this);
+  message_question(msg.c_str(), "Sequence Properties", this);
 }
 
 
