@@ -15,6 +15,13 @@ fmriResult fmri_eval(const Data<float,1>& timecourse, const Data<float,1>& desig
   float maxdesign=max(designvec);
   float mindesign=min(designvec);
 
+  // Calculate baseline
+  int nbaseline=0;
+  for(int i=0; i<nrep; i++) {
+    if(designvec(i)) break;
+    nbaseline++;
+  }
+  if(nbaseline) result.Sbaseline=mean(timecourse(Range(0,nbaseline-1)));
 
   // calculate fMRI contrast
   int nrest=0;
