@@ -500,9 +500,9 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
       continue;
     }
 
-    bool do_trace_cache=do_trace; do_trace=false; // Do not trace reading of single files
+    bool do_trace_cache=get_trace_status(); set_trace_status(false); // Do not trace reading of single files
     int readresult=FileIO::autoread(onepdmap,dirfilename,opts_copy,protocol_template);
-    do_trace=do_trace_cache;
+    set_trace_status(do_trace_cache);
     if(progmeter && progmeter->increase_counter(dirfilename.c_str())) break;//cancel if the ProgressMeter says so
 
     if(readresult<0) {
@@ -774,7 +774,7 @@ STD_string FileIO::autoformats_str(const STD_string& indent) {
 
 //////////////////////////////////////////////////////////////
 
-bool FileIO::do_trace=true;
+bool FileIOTrace::do_trace=true;
 
 STD_string FileFormat::select_write_datatype(const Protocol &prot,const FileWriteOpts& opts){
   if(opts.datatype != AUTOTDATAYPESTR)
