@@ -2,7 +2,7 @@
                           fileio.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2019 by Thies Jochimsen
+    copyright            : (C) 2000-2021 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -47,10 +47,39 @@ static const char* dataDimLabel[]={"time",    "slice",  "phase",  "read"};
 AVOID_CC_WARNING(dataDimLabel)
 
 
+//////////////////////////////////////////////////////////////////////////
+
+// helper class to enable/disable tracing
+class FileIOTrace {
+
+ public:
+  /**
+    * Returns whether tracing via stdout is enabled/disabled
+    */
+  static bool get_trace_status() {return do_trace;}
+
+  /**
+    * Enables/disables tracing via stdout
+    */
+  static void set_trace_status(bool stat) {do_trace=stat;}
+
+
+ protected:
+  static logPriority loglevel() {if(get_trace_status()) return infoLog; else return normalDebug;}
+
+
+ private:
+  static bool do_trace;
+
+};
+
+
+//////////////////////////////////////////////////////////////////////////
+
 /**
   * Structure to accomodate autoread/autwrite functionality. Please refer to (\ref fileio_doc ) for a detailed description of this module.
   */
-class FileIO {
+class FileIO : public FileIOTrace {
 
  public:
 
@@ -70,7 +99,7 @@ class FileIO {
   /**
     * Writes out protocol-data map 'pdmap' to file(s) filename, autodetects file format according to file extension.
     * Write options are given by 'opts'.
-    * Returns number of slices sucessfully written, or -1 if it fails.
+    * Returns number of slices successfully written, or -1 if it fails.
     */
   static int autowrite(const ProtocolDataMap& pdmap, const STD_string& filename, const FileWriteOpts& opts);
 
@@ -85,22 +114,10 @@ class FileIO {
   static STD_string autoformats_str(const STD_string& indent="");
 
 
-  /**
-    * Returns whether tracing via stdout is enabled/disabled
-    */
-  static bool get_trace_status() {return do_trace;}
-
-  /**
-    * Enables/disables tracing via stdout
-    */
-  static void set_trace_status(bool stat) {do_trace=stat;}
-
 
   static const char* get_compName(); // For debugging FilieIO component
 
  private:
-  static logPriority loglevel() {if(do_trace) return infoLog; else return normalDebug;}
-  static bool do_trace;
 
   static int read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const FileReadOpts& opts, const Protocol& protocol_template,ProgressMeter* progmeter=0);
 
