@@ -16,7 +16,7 @@ struct AsciiFormat : public FileFormat {
   }
   int read(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol& prot) {
     STD_string ascfile;
-    ::load(ascfile,filename);
+    if(::load(ascfile,filename)<0) return -1;
     unsigned int nelements=tokens(ascfile).size();
     if(tolowerstr(opts.dialect)=="tcourse") data.resize(nelements,1,1,1);
     else                                    data.resize(1,nelements,1,1);
@@ -89,7 +89,7 @@ struct PosFormat : public FileFormat {
     int ny=data.extent(2);
     STD_ofstream ofs(filename.c_str());
     if(ofs.bad()) return -1;
-    for(int i=0; i<data.numElements(); i++) {
+    for(unsigned int i=0; i<data.numElements(); i++) {
       TinyVector<int,4> index=data.create_index(i);
       if(data(index)>0.0) {
         int ix=index(3);
@@ -153,7 +153,7 @@ struct IndexFormat : public FileFormat {
     STD_ofstream ofs(filename.c_str());
     if(ofs.bad()) return -1;
     bool addval=(opts.dialect=="addval");
-    for(int i=0; i<data.numElements(); i++) {
+    for(unsigned int i=0; i<data.numElements(); i++) {
       TinyVector<int,4> index=data.create_index(i);
       if(data(index)) {
         if(addval) ofs << data(index) << " ";
