@@ -492,7 +492,7 @@ struct DicomFormat : public FileFormat {
         copy<s32bit> (pix,data,shape,mosaic_mult);
         prot.system.set_data_type(TypeTraits::type2label((s32bit)0));
         break;
-      default: ODINLOG(odinlog,errorLog) <<  "pixel representation not supportet"<< STD_endl;
+      default: ODINLOG(odinlog,errorLog) <<  "pixel representation not supported"<< STD_endl;
     }
 
 #ifdef ODIN_DEBUG
@@ -519,7 +519,7 @@ struct DicomFormat : public FileFormat {
 
 
 
-    STD_string unknown="Unknown";
+    STD_string unknown=ODIN_UNKNOWN_STR;
 
     // Date/time stuff
     STD_string scandate;
@@ -815,7 +815,7 @@ struct DicomFormat : public FileFormat {
     LDRfileName dstdir; dstdir.set_dir(true);
     dstdir=fname.get_dirname()+SEPARATOR_STR+fname.get_basename_nosuffix()+STD_string("_dcm");
     if( createdir(dstdir.c_str()) && (!checkdir(dstdir.c_str())) ) {
-      ODINLOG(odinlog,errorLog) << "Cannot create directoy " << dstdir << STD_endl;
+      ODINLOG(odinlog,errorLog) << "Cannot create directory " << dstdir << STD_endl;
       return -1;
     }
     STD_string dcmdirfname=dstdir+SEPARATOR_STR+"DICOMDIR";
@@ -1076,7 +1076,7 @@ struct DicomFormat : public FileFormat {
 
 
       // preserving (floating point) values
-      if(!opts.noscale && opts.dialect!="siemens") {
+      if(!opts.noscale) {
         double minval_out=min(data);
         double maxval_out=max(data);
         double slope=secureDivision(maxval_out-minval_out, max_stored-min_stored);
