@@ -77,8 +77,8 @@ struct InterfileFormat : public FileFormat {
     LONGEST_INT offset=atoi(parse_header_entry(header, "data offset in bytes").c_str());
     ODINLOG(odinlog,normalDebug) << "offset="<< offset << STD_endl;
 
-    STD_string endianess=shrink(parse_header_entry(header, "imagedata byte order"));
-    ODINLOG(odinlog,normalDebug) << "endianess="<< endianess << STD_endl;
+    STD_string endianness=shrink(parse_header_entry(header, "imagedata byte order"));
+    ODINLOG(odinlog,normalDebug) << "endianness="<< endianness << STD_endl;
 
     STD_string format=parse_header_entry(header, "number format");
     ODINLOG(odinlog,normalDebug) << "format="<< format << STD_endl;
@@ -95,7 +95,7 @@ struct InterfileFormat : public FileFormat {
     char* ptr_byteorder=(char*)ptr; // default
     bool swapped=false;
 
-    bool little_endian_file=(endianess=="LITTLEENDIAN");
+    bool little_endian_file=(endianness=="LITTLEENDIAN");
     if(little_endian_file != little_endian_byte_order()) {
 
       ptr_byteorder=new char[nbytes];
