@@ -24,7 +24,7 @@ struct NiftiFormat : public FileFormat{
     return result;
   }
 
-  float read_orientation(const nifti_image &ni,Geometry &geometry, const FileReadOpts& opts) {
+  bool read_orientation(const nifti_image &ni,Geometry &geometry, const FileReadOpts& opts) {
     Log<FileIO> odinlog("NiftiFormat","read_orientation");
 
     float spatscale=1.0;
@@ -84,9 +84,8 @@ struct NiftiFormat : public FileFormat{
 
       ODINLOG(odinlog,normalDebug) << "set up gradrot matrix " << geometry.get_gradrotmatrix().print() << STD_endl;
       ODINLOG(odinlog,normalDebug) << "set up center (offset) " << geometry.get_center().printbody() << STD_endl;
-      return ni.scl_slope?:1;
     }
-    return 1;
+    return true;
   }
 
   template<class T> void copy_from(const T* src,Data<float,4> &dst, const FileReadOpts& opts) {
@@ -99,7 +98,7 @@ struct NiftiFormat : public FileFormat{
 
     nifti_image* ni=nifti_image_read(filename.c_str(), true);
 
-    float scale=read_orientation(*ni,prot.geometry,opts);
+    if(!read_orientation(*ni,prot.geometry,opts)) return -1;
 
     data.resize(
         ni->ndim>=4 ? ni->dim[4]:1,
@@ -109,7 +108,7 @@ struct NiftiFormat : public FileFormat{
     );
     const TinyVector<int, 4> shape(data.shape());
     ODINLOG(odinlog,normalDebug) << "shape/ndim=" << shape << "/" << ni->ndim << STD_endl;
-    if(ni->nvox!=product(shape)) {
+    if(int(ni->nvox)!=product(shape)) {
       ODINLOG(odinlog,errorLog)  << "ni->nvox=" << ni->nvox << " != product(shape)=" << product(shape) << STD_endl;
     }
 
@@ -156,8 +155,14 @@ struct NiftiFormat : public FileFormat{
     ODINLOG(odinlog,normalDebug) << "type=" << type << STD_endl;
     if(type=="")return -1;
 
-    //scale data
-    data*=scale;
+    if(ni->nifti_type>0) { // only for non-ANALYZE
+      if(ni->scl_slope!=1.0 || ni->scl_inter!=0.0) {
+        ODINLOG(odinlog,normalDebug) << "ni->scl_slope/ni->scl_inter=" << ni->scl_slope << "/" <<ni->scl_inter << STD_endl;
+        if(ni->scl_slope) { // apply only if slope is non-zero
+          data=data*ni->scl_slope+ni->scl_inter;
+        }
+      }
+    }
 
     //set some metadata
     prot.system.set_data_type(type);
@@ -261,7 +266,7 @@ struct NiftiFormat : public FileFormat{
     STD_string type=select_write_datatype(prot,opts);
     ODINLOG(odinlog,normalDebug) << "type=" << type << STD_endl;
 
-    JDXfileName fname(filename);
+    LDRfileName fname(filename);
 
     Protocol protcopy(prot);
     Geometry& geo=protcopy.geometry;
