@@ -62,9 +62,9 @@ bool write_png(const char *filename, Data<u8bit,4> &buff){
 
   /* png needs a pointer to each row */
   u8bit *rp=buff.c_array();
-  png_byte** row_pointers= new png_byte*[buff.shape()(thirdDim)];
-  for (unsigned short r=0; r<buff.shape()(thirdDim); r++)
-    row_pointers[r]=(png_byte*)&rp[r*buff.shape()(fourthDim)];
+  png_byte** row_pointers= new png_byte*[buff.shape()(2)];
+  for (unsigned short r=0; r<buff.shape()(2); r++)
+    row_pointers[r]=(png_byte*)&rp[r*buff.shape()(3)];
   png_set_rows(png_ptr, info_ptr, row_pointers);
 
   /* This is the easy way.  Use it if you already have all the
