@@ -28,7 +28,7 @@ struct FilterChainData; // forward declaration
 /**
   * A chain of filter functors.
   */
-class FilterChain {
+class FilterChain : public FileIOTrace {
 
  public:
 
