@@ -89,7 +89,11 @@ bool FilterAlign::process(Data<float,4>& data, Protocol& prot) const {
   Data<float,4> outdata(ntime,dst_shape(0),dst_shape(1),dst_shape(2));
 
   for(int itime=0; itime<data.extent(timeDim); itime++) {
+#ifdef BLITZ_REPLACEMENT
+    outdata(itime,all,all,all)=gridder.operator()<3>(data(itime,all,all,all)); // syntax for blitz_replacement
+#else
     outdata(itime,all,all,all)=gridder(data(itime,all,all,all));
+#endif
   }
   data.reference(outdata);
 
