@@ -2,7 +2,7 @@
 #include "utils.h"
 
 void FilterMin::init(){
-  thresh.set_description("Minumum value");
+  thresh.set_description("Minimum value");
   append_arg(thresh,"thresh");
 }
 
