@@ -2,7 +2,7 @@
                           filter_scale.h  -  description
                              -------------------
     begin                : Thu Jan 31 2008
-    copyright            : (C) 2000-2019 by Thies Jochimsen
+    copyright            : (C) 2000-2021 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -25,7 +25,7 @@ class FilterMin : public FilterStep {
   LDRfloat thresh;
 
   STD_string label() const {return "min";}
-  STD_string description() const {return "Clip all values below mininum value";}
+  STD_string description() const {return "Clip all values below minimum value";}
   bool process(Data<float,4>& data, Protocol& prot) const;
   FilterStep*  allocate() const {return new FilterMin();}
   void init();
@@ -55,7 +55,7 @@ protected:
 
 class FilterTypeMin : public FilterType {
   STD_string label() const {return "typemin";}
-  STD_string description() const {return "Clip all values below mininum of a specific datatype";}
+  STD_string description() const {return "Clip all values below minimum of a specific datatype";}
   bool process(Data<float,4>& data, Protocol& prot) const;
   FilterStep*  allocate() const {return new FilterTypeMin();}
 };
