@@ -1,13 +1,29 @@
 #include "filter_convolve.h"
 #include "complexdata.h"
+#include "fitting.h"
+
+
+class FilterFindFWHM : public MinimizationFunction {
+ public:
+  FilterFindFWHM(const LDRfilter& kernel) : kern(kernel) {}
+
+  virtual unsigned int numof_fitpars() const {return 1;}
+  virtual float evaluate(const fvector& fv) const {return fabs(kern.calculate(fv[0])-0.5);}
+
+ private:
+  const LDRfilter& kern;
+};
+
+////////////////////////////////////////////////////////////////////////////////
+
 
 
 void FilterConvolve::init() {
   kernel.set_description("convolution kernel");
   append_arg(kernel,"kernel");
 
-  kerneldiameter.set_unit(ODIN_SPAT_UNIT).set_description("kernel diameter");
-  append_arg(kerneldiameter,"kerneldiameter");
+  kernelwidth.set_unit(ODIN_SPAT_UNIT).set_description("full-width-at-half-maximum of kernel");
+  append_arg(kernelwidth,"kernelwidth");
 }
 
 bool FilterConvolve::process(Data<float,4>& data, Protocol& prot) const {
@@ -15,6 +31,20 @@ bool FilterConvolve::process(Data<float,4>& data, Protocol& prot) const {
 
   Range all=Range::all();
 
+
+  FilterFindFWHM findfwhm(kernel);
+  DownhillSimplex downhill(findfwhm);
+  fvector starting_point(1); starting_point[0]=0.5;
+  fvector step_size(1); step_size[0]=0.1;
+  fvector fitresult(1);
+  float relfwhm=1.0;
+  if(downhill.get_minimum_parameters(fitresult, starting_point, step_size)) {
+    relfwhm=fitresult[0];
+  }
+  float kerneldiameter=secureDivision(kernelwidth,relfwhm);
+  ODINLOG(odinlog,normalDebug) << "kernelwidth/relfwhm/kerneldiameter=" << kernelwidth << "/" << relfwhm << "/" << kerneldiameter << STD_endl;
+
+
   TinyVector<int,4> shape=data.shape();
   TinyVector<int,3> spatshape(shape(sliceDim), shape(phaseDim), shape(readDim));
 
