@@ -2,9 +2,14 @@
 #include "fitting.h"
 
 void FilterDeTrend::init(){
+
   nlow=5;
   nlow.set_description("Number of low frequency components to be removed");
   append_arg(nlow,"nlow");
+
+  zeromean=false;
+  zeromean.set_description("Zero mean of resulting timecourse");
+  append_arg(zeromean,"zeromean");
 }
 
 bool FilterDeTrend::process(Data<float,4>& data, Protocol& prot) const {
@@ -25,8 +30,12 @@ bool FilterDeTrend::process(Data<float,4>& data, Protocol& prot) const {
       for(int iphase=0; iphase<shape(2); iphase++) {
         for(int iread=0; iread<shape(3); iread++) {
           linf.fit(data(all,islice,iphase,iread));
-          float meanval=0.5*(shape(0)-1)*linf.m.val;
-          for(int irep=0; irep<shape(0); irep++) data(irep,islice,iphase,iread)-=(irep*linf.m.val-meanval);
+          if(zeromean) {
+            for(int irep=0; irep<shape(0); irep++) data(irep,islice,iphase,iread)-=(irep*linf.m.val+linf.c.val);
+          } else {
+            float meanval=0.5*(shape(0)-1)*linf.m.val;
+            for(int irep=0; irep<shape(0); irep++) data(irep,islice,iphase,iread)-=(irep*linf.m.val-meanval);
+          }
         }
       }
     }
@@ -40,10 +49,12 @@ bool FilterDeTrend::process(Data<float,4>& data, Protocol& prot) const {
     lowdata.congrid(lowshape);
     lowdata.congrid(shape);
 
-    for(int islice=0; islice<lowshape(1); islice++) {
-      for(int iphase=0; iphase<lowshape(2); iphase++) {
-        for(int iread=0; iread<lowshape(3); iread++) {
-          lowdata(all,islice,iphase,iread)-=mean(lowdata(all,islice,iphase,iread));
+    if(!zeromean) {
+      for(int islice=0; islice<lowshape(1); islice++) {
+        for(int iphase=0; iphase<lowshape(2); iphase++) {
+          for(int iread=0; iread<lowshape(3); iread++) {
+            lowdata(all,islice,iphase,iread)-=mean(lowdata(all,islice,iphase,iread));
+          }
         }
       }
     }
