@@ -1,9 +1,9 @@
 #include "filter_edit.h"
 
 void FilterEdit::init(){
-  pos.set_description("Position/range string in the format (timeframe,slicepos,phasepos,readpos)");
+  pos.set_description("string in the format (timerange,slicerange,phaserange,readrange)");
   append_arg(pos,"pos");
-  val.set_description("new value of voxel");
+  val.set_description("value");
   append_arg(val,"val");
 }
 
