@@ -1,7 +1,7 @@
 #include "filter_lowpass.h"
 #include "complexdata.h"
 
-#include <odinpara/jdxfilter.h>
+#include <odinpara/ldrfilter.h>
 
 void FilterLowPass::init(){
   freq=0.0;
@@ -31,7 +31,7 @@ bool FilterLowPass::process(Data<float,4>& data, Protocol& prot) const {
 
   ODINLOG(odinlog,normalDebug) << "plateauindex/cutoffindex=" << plateauindex << "/" << cutoffindex << STD_endl;
 
-  JDXfilter transition;
+  LDRfilter transition;
   transition.set_function("Gauss");
 
   for(int i=0; i<(centindex+1); i++) {
