@@ -50,6 +50,11 @@ void FilterGenMask::init(){
 }
 
 bool FilterGenMask::process(Data<float,4>& data, Protocol& prot) const {
+  Log<Filter> odinlog(c_label(),"process");
+  if(max<=min) {
+    ODINLOG(odinlog,warningLog) << "max(" << max << ") <= min(" << min << ")" << STD_endl;
+  }
+
   TinyVector<int,4> indexvec;
   for(unsigned int i=0; i<data.numElements(); i++) {
     indexvec=data.create_index(i);
@@ -60,6 +65,21 @@ bool FilterGenMask::process(Data<float,4>& data, Protocol& prot) const {
   return true;
 }
 
+///////////////////////////////////////////////////////////////////////////
+
+
+bool FilteNonZeroMask::process(Data<float,4>& data, Protocol& prot) const {
+  Log<Filter> odinlog(c_label(),"process");
+
+  TinyVector<int,4> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    if(data(indexvec)!=0.0) data(indexvec)=1.0;
+    else data(indexvec)=0.0;
+  }
+  return true;
+}
+
 
 ///////////////////////////////////////////////////////////////////////////
 
@@ -114,15 +134,17 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
 
 
   // 1st method: find first minimum
-  float thresh_min=0.0;
+  float thresh=0.0;
   int islot;
   for(islot=slotstart; islot<(nslots-1); islot++) {
     if(hist(islot+1)>hist(islot)) {
-      thresh_min=(islot+1)*step; // use one step after min for threshold
+      thresh=(islot+1)*step; // use one step after min for threshold
       break;
     }
   }
-  ODINLOG(odinlog,normalDebug) << "islot/thresh(min)=" << "/" << islot << "/" << thresh_min << STD_endl; 
+  ODINLOG(odinlog,significantDebug) << "slot/thresh(min)=" << "/" << islot << "/" << thresh << STD_endl; 
+
+
 
 
   // 2nd method: use exponential+linear fit of histogram
@@ -147,41 +169,39 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
   expfunc.M.val=-1;
   expfunc.C.val=0.0;
 
-  if(!fitter.fit(hist4fit, ysigma, xvals)) return false;
+  if(fitter.fit(hist4fit, ysigma, xvals, 1000, 1e-3)) {
 
-  ODINLOG(odinlog,normalDebug) << "A=" << expfunc.A << STD_endl; 
-  ODINLOG(odinlog,normalDebug) << "lambda=" << expfunc.lambda << STD_endl; 
-  ODINLOG(odinlog,normalDebug) << "M=" << expfunc.M << STD_endl; 
-  ODINLOG(odinlog,normalDebug) << "C=" << expfunc.C << STD_endl; 
+    ODINLOG(odinlog,normalDebug) << "A=" << expfunc.A << STD_endl; 
+    ODINLOG(odinlog,normalDebug) << "lambda=" << expfunc.lambda << STD_endl; 
+    ODINLOG(odinlog,normalDebug) << "M=" << expfunc.M << STD_endl; 
+    ODINLOG(odinlog,normalDebug) << "C=" << expfunc.C << STD_endl; 
 
 
-  if(dump_histogram_fit_fname!="") {
-    ODINLOG(odinlog,infoLog) << "dumping histogram fit to file " << dump_histogram_fit_fname << STD_endl; 
+    if(dump_histogram_fit_fname!="") {
+      ODINLOG(odinlog,infoLog) << "dumping histogram fit to file " << dump_histogram_fit_fname << STD_endl; 
+      hist4fit=expfunc.get_function(xvals); // overwrite real histogram by fit
+      Data<float,1> histfit(nslots); histfit=0.0;
+      for(int islot=0; islot<nslots4fit; islot++) histfit(slotstart+islot)=hist4fit(islot);
+      histfit.write_asc_file(dump_histogram_fit_fname);
+    }
 
-    hist4fit=expfunc.get_function(xvals); // overwrite real histogram by fit
 
-    Data<float,1> histfit(nslots); histfit=0.0;
-    for(int islot=0; islot<nslots4fit; islot++) histfit(slotstart+islot)=hist4fit(islot);
+    for(islot=0; islot<nslots4fit; islot++) {
+      float expval=expfunc.A.val * exp (expfunc.lambda.val * islot);
+      float linval=expfunc.M.val*islot + expfunc.C.val;
+      ODINLOG(odinlog,normalDebug) << "expval/linval["<< islot << "]=" << expval << "/" << linval << STD_endl;
+      if(linval>=expval) break; // seth threshold where exponential falls below linear term
+    }
+    int threshslot_fit=slotstart+islot;
+    float thresh_fit=step*threshslot_fit;
+    ODINLOG(odinlog,significantDebug) << "slot/thresh(fit)=" << "/" << threshslot_fit << "/" << thresh_fit << STD_endl; 
+
+    thresh=STD_min(thresh, thresh_fit); // combination of both methods
+    ODINLOG(odinlog,significantDebug) << "thresh=" << "/" << thresh << STD_endl; 
 
-    histfit.write_asc_file(dump_histogram_fit_fname);
   }
 
 
-  for(islot=0; islot<nslots4fit; islot++) {
-    float expval=expfunc.A.val * exp (expfunc.lambda.val * islot);
-    float linval=expfunc.M.val*islot + expfunc.C.val;
-    ODINLOG(odinlog,normalDebug) << "expval/linval["<< islot << "]=" << expval << "/" << linval << STD_endl;
-    if(linval>=expval) break; // seth threshold where exponential falls below linear term
-  }
-  int threshslot_fit=slotstart+islot;
-  float thresh_fit=step*threshslot_fit;
-  ODINLOG(odinlog,normalDebug) << "threshslot_fit/thresh_fit=" << threshslot_fit << "/" << thresh_fit << STD_endl; 
-
-
-
-  float thresh=STD_min(thresh_min, thresh_fit); // combination of both methods
-
-
   TinyVector<int,4> indexvec;
   for(unsigned int i=0; i<data.numElements(); i++) {
     indexvec=data.create_index(i);
