@@ -10,7 +10,7 @@ bool str2range(const STD_string& str, Range& range, int srcsize) {
   if(colsize==2) increment=atoi(tokscol[1].c_str());
   STD_string fromto=tokscol[0];
   bool result=false;
-  if(fromto=="all") {
+  if(tolowerstr(fromto)=="all") {
     range=Range::all();
     result=true;
   } else {
@@ -43,3 +43,5 @@ bool str2range(const STD_string& str, Range& range, int srcsize) {
   }
   return result;
 }
+
+STD_string str2range_usage() {return "single position, or \'all\', or explict range, optionally with increment (e.g. 1-10:3)";}
