@@ -2,7 +2,7 @@
                           filter_range.h  -  description
                              -------------------
     begin                : Tue Jan 29 2008
-    copyright            : (C) 2000-2019 by Thies Jochimsen
+    copyright            : (C) 2000-2021 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,6 +22,7 @@
 
 
 bool str2range(const STD_string& str, Range& range, int srcsize);
+STD_string str2range_usage();
 
 
 template<int Dir>
@@ -82,7 +83,7 @@ class FilterRange : public FilterStep {
   FilterStep*  allocate() const {return new FilterRange<Dir>();}
 
   void init() {
-    range.set_description("Single value or range, optionally with increment (e.g. 1-10:3)");
+    range.set_description(str2range_usage());
     append_arg(range,"range");
   }
 };
