@@ -79,9 +79,10 @@ bool FilterIsotrop::process(Data<float,4>& data, Protocol& prot) const {
   );
 
   float m;
-  if(size!=0)m=size;
+  if(size>0) m=size;
   else m=min(vox_size);
   vox_mult=vox_size/m;
+  ODINLOG(odinlog,normalDebug) << "Regridding to isotropic "  << m << ODIN_SPAT_UNIT << STD_endl;
 
   ODINLOG(odinlog,normalDebug) << "current voxel_size: " << vox_size << STD_endl;
   ODINLOG(odinlog,normalDebug) << "shape scaling vector: " << vox_mult << STD_endl;
