@@ -28,9 +28,9 @@ bool swapdim(Data<float,4>& data, Geometry& geo,const direction newread,const di
   for(direction i=readDirection;i<n_directions;i=direction(i+1))
     fov[i]=geo.get_FOV(i);
 
-  //transpose the data (data.transposeSelf(firstDim,n_directions-sliceDirection,n_directions-phaseDirection,n_directions-readDirection) would do nothing
+  //transpose the data (data.transposeSelf(0,n_directions-sliceDirection,n_directions-phaseDirection,n_directions-readDirection) would do nothing
   data.transposeSelf(
-      firstDim,
+      0,
       n_directions-newslice,
       n_directions-newphase,
       n_directions-newread
