@@ -31,7 +31,7 @@ class FilterSwapdim : public FilterStep
   LDRstring newread,newphase,newslice;
 
   STD_string label() const {return "swapdim";}
-  STD_string description() const {return "swap/reflect dimensions by specifying a direction triple with optional reflection sign appended";}
+  STD_string description() const {return "swap/reflect/transpose dimensions by specifying a direction triple with optional reflection sign appended";}
   bool process(Data<float,4>& data, Protocol& prot)const;
   FilterStep*  allocate() const {return new FilterSwapdim();}
   static bool selChannel(STD_string name, direction &dir, int& sign);
