@@ -3,7 +3,7 @@
 
 void FilterSplice::init() {
   for(int i=0; i<n_dataDim; i++) dir.add_item(dataDimLabel[i]);
-  dir.add_item("none"); // default to throw error when no dim is given
+  dir.add_item(ODIN_NONE_STR); // default to throw error when no dim is given
   dir.set_actual(dir.n_items()-1);
   dir.set_cmdline_option("dir").set_description("dimension of the data to be spliced");
   append_arg(dir,"dir");
@@ -12,7 +12,7 @@ void FilterSplice::init() {
 bool FilterSplice::process(FileIO::ProtocolDataMap& pdmap) const {
   Log<Filter> odinlog(c_label(),"process");
 
-  if(dir=="none") {
+  if(dir==ODIN_NONE_STR) {
     ODINLOG(odinlog,errorLog) << "no dimension given for splice" << STD_endl;
     return false;
   }
