@@ -16,19 +16,18 @@ bool FilterTile::process(Data<float,4>& data, Protocol& prot) const {
   int nphase=data.extent(2);
   int nread=data.extent(3);
 
-  if(cols<=0 || cols>nslice) {
-    ODINLOG(odinlog,errorLog) << "cols=" << int(cols) << " out of range" << STD_endl;
-    return false;
-  }
+  int tilecols=cols;
+  tilecols=STD_max(tilecols,1);
+  tilecols=STD_min(tilecols,nslice);
 
 
-  int rows=nslice/cols;
-  if(nslice%cols) rows++;
+  int rows=nslice/tilecols;
+  if(nslice%tilecols) rows++;
 
-  ODINLOG(odinlog,normalDebug) << "nslice/cols/rows=" << nslice << "/" << int(cols) << "/" << rows << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "nslice/cols/rows=" << nslice << "/" << tilecols << "/" << rows << STD_endl;
 
   int newnphase=rows*nphase;
-  int newnread=cols*nread;
+  int newnread=tilecols*nread;
 
   Data<float,4> outdata(nrep,1,newnphase,newnread); outdata=0.0;
 
@@ -41,7 +40,7 @@ bool FilterTile::process(Data<float,4>& data, Protocol& prot) const {
     outdata(all, 0, Range(rowoffset, rowoffset+nphase-1), Range(coloffset, coloffset+nread-1))=data(all,islice,all,all);
 
     icol++;
-    if(icol>=cols) {
+    if(icol>=tilecols) {
       icol=0;
       irow++;
     }
