@@ -33,7 +33,7 @@ struct GslData4Fit {
 ////////////////////////////////////////////////////////////////
 
 Array<float,1> ModelFunction::get_function(const Array<float,1>& xvals) const {
-  int n=xvals.extent(firstDim);
+  int n=xvals.extent(0);
   Array<float,1> result(n);
   for(int i=0; i<n; i++) {
     result(i)=evaluate_f(xvals(i));
@@ -553,18 +553,18 @@ DownhillSimplex::~DownhillSimplex() {
 }
 
 
-fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_point, const fvector& step_size, unsigned int max_iterations, double tolerance) {
+bool DownhillSimplex::get_minimum_parameters(fvector& result, const fvector& starting_point, const fvector& step_size, unsigned int max_iterations, double tolerance) {
   Log<OdinData> odinlog("DownhillSimplex","get_minimum_parameters");
 
-  fvector result(ndim);
+  result.resize(ndim);
 
   if(starting_point.size()!=ndim) {
     ODINLOG(odinlog,errorLog) << "size mismatch: starting_point.size()=" << starting_point.size() << ", ndim=" << ndim << STD_endl;
-    return result;
+    return false;
   }
   if(step_size.size()!=ndim) {
     ODINLOG(odinlog,errorLog) << "size mismatch: starting_point.size()=" << starting_point.size() << ", ndim=" << ndim << STD_endl;
-    return result;
+    return false;
   }
  
   for(unsigned int idim=0; idim<ndim; idim++) {
@@ -607,7 +607,7 @@ fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_point, c
   ODINLOG(odinlog,normalDebug) << "result" << result << STD_endl;
   ODINLOG(odinlog,normalDebug) << "min value=" << gsldata->s->fval << STD_endl;
     
-  return result;
+  return status==GSL_SUCCESS;
 }
 
 //////////////////////////////////////////////////////////////
@@ -698,7 +698,10 @@ bool FunctionFitDownhillSimplex::fit(const Array<float,1>& yvals,
     for(int irun=0; irun<nruns; irun++) {
       for(unsigned int i=0; i<yvals_cache.size(); i++) yvals_cache(i)=yvals_cache_orig(i)+rd.gaussian(ysigma_cache(i));
 
-      fvector mcminvec=ds->get_minimum_parameters(starting_point, step_size, max_iterations, tolerance);
+      fvector mcminvec;
+      if(!ds->get_minimum_parameters(mcminvec, starting_point, step_size, max_iterations, tolerance)) {
+        return false;
+      }
       for(unsigned int ipar=0; ipar<npars; ipar++) fitpar_ensemble[ipar](irun)=mcminvec[ipar];
 
     }
@@ -713,7 +716,10 @@ bool FunctionFitDownhillSimplex::fit(const Array<float,1>& yvals,
 
 
   // final run without noise
-  fvector minvec=ds->get_minimum_parameters(starting_point, step_size, max_iterations, tolerance);
+  fvector minvec;
+  if(!ds->get_minimum_parameters(minvec, starting_point, step_size, max_iterations, tolerance)) {
+    return false;
+  }
   for(unsigned int ipar=0; ipar<npars; ipar++) func->get_fitpar(ipar).val=minvec[ipar];
 
   return true;
@@ -786,7 +792,10 @@ class FunctionFitTest : public UnitTest {
     fvector step_size(2);
     step_size=1.0;
 
-    fvector dsresult=ds.get_minimum_parameters(starting_point, step_size);
+    fvector dsresult;
+    if(!ds.get_minimum_parameters(dsresult,starting_point, step_size)) {
+      ODINLOG(odinlog,errorLog) << "DownhillSimplex fit failed" << STD_endl;
+    }
 
     fvector dsexpected(2);
     dsexpected[0]=2.0;
