@@ -142,8 +142,13 @@ bool solve_linear_lapack(Data<T,1>& result, const Data<T,2>& A, const Data<T,1>&
   ODINLOG(odinlog,normalDebug) << "M/N=" << M << "/" << N << STD_endl;
 
 
-  Array<T,2> A_fortran(A.shape(), ColumnMajorArray<2>()); // Array with Fortran storage order
-  A_fortran=A; // creates unique copy
+  // Array with Fortran storage order
+  Array<T,2> A_fortran(N,M);
+  for(int in=0; in<N; in++) {
+    for(int im=0; im<M; im++) {
+      A_fortran(in,im)=A(im,in);
+    }
+  }
 
   Array<T,1> B_X(M); // Use Copy because it is used for in- and output
   B_X=b;
@@ -415,9 +420,13 @@ Data<float,1> eigenvalues(const Data<float,2>& A) {
 
 #ifdef HAVE_LAPACK
 
-  Array<float,2> A_fortran(A.shape(), ColumnMajorArray<2>()); // Array with Fortran storage order
-  A_fortran=A; // creates unique copy
-
+  // Array with Fortran storage order
+  Array<float,2> A_fortran(N,N);
+  for(int i=0; i<N; i++) {
+    for(int j=0; j<N; j++) {
+      A_fortran(i,j)=A(j,i);
+    }
+  }
 
   char JOBZ='N';
   char UPLO='U';
