@@ -41,6 +41,9 @@ STD_string Step<T>::args_description() const {
     STD_string unit=args[i].get_unit();
     if(unit!="") result+=" ["+unit+"]";
 
+    STD_string defval=args[i].printvalstring();
+    if(defval!="" && defval!=ODIN_NONE_STR) result+=" (default="+defval+")";
+
     svector alt=args[i].get_alternatives();
     if(alt.size()) result+=" ("+tokenstring(alt,0)+")";
     if(i<(nargs-1)) result+=",";
@@ -49,6 +52,20 @@ STD_string Step<T>::args_description() const {
 }
 
 
+template <class T>
+STD_string Step<T>::args_values() const {
+  int nargs=args.numof_pars();
+  STD_string result;
+  for(int i=0; i<nargs; i++) {
+    result+=args[i].printvalstring();
+    STD_string unit=args[i].get_unit();
+    if(unit!="") result+="["+unit+"]";
+    if(i<(nargs-1)) result+=",";
+  }
+  return result;
+}
+
+
 template <class T>
 void Step<T>::append_opts(LDRblock& parblock) {
   parblock.merge(args);
