@@ -154,9 +154,9 @@ Geometry::Geometry(const STD_string& label) : LDRblock(label) {
   nSlices.set_description("Number of sices");
   sliceThickness.set_unit(ODIN_SPAT_UNIT).set_cmdline_option("st").set_description("Slice thickness");
   sliceDistance.set_unit(ODIN_SPAT_UNIT).set_cmdline_option("sd").set_description("Inter-slice distance (from center to center)");
-  heightAngle.set_description("height rotation angle").set_cmdline_option("ah");
-  azimutAngle.set_description("azimuthal rotation angle").set_cmdline_option("aa");
-  inplaneAngle.set_description("inplane rotation angle").set_cmdline_option("ai");
+  heightAngle.set_unit(ODIN_ANGLE_UNIT).set_description("height rotation angle").set_cmdline_option("ah");
+  azimutAngle.set_unit(ODIN_ANGLE_UNIT).set_description("azimuthal rotation angle").set_cmdline_option("aa");
+  inplaneAngle.set_unit(ODIN_ANGLE_UNIT).set_description("inplane rotation angle").set_cmdline_option("ai");
   reverseSlice.set_description("Reverse direction of slice vector");
   Reset.set_description("Reset to default values");
   Transpose.set_description("Transpose in-plane");
