@@ -167,8 +167,8 @@ class Base64 {
 
 /////////////////////////////////////////////////////////////////////////////////////
 
-struct LDRendianess : public LDRenum {
-  LDRendianess() : LDRenum("Endianess") {
+struct LDRendianness : public LDRenum {
+  LDRendianness() : LDRenum("Endianness") {
     add_item("littleEndian",int(true));
     add_item("bigEndian",int(false));
     LDRenum::operator = (int(little_endian_byte_order()));
@@ -238,12 +238,12 @@ bool LDRarray<A,J>::encode(STD_string* ostring, STD_ostream* ostream) const {
   unsigned char* data=(unsigned char*)A::c_array();
   if(!data) return false;
 
-  LDRendianess endianess;
+  LDRendianness endianness;
   J ldrdummy;
   
   STD_string header=STD_string(ENCODING_ID_STR)
                     +b64.get_encoding_id()+","
-                    +endianess.LDRenum::operator STD_string ()+","
+                    +endianness.LDRenum::operator STD_string ()+","
                     +ldrdummy.get_typeInfo()+"\n";
 
   if(ostring) (*ostring) += header;
@@ -351,10 +351,10 @@ bool LDRarray<A,J>::parsevalstring(const STD_string& parstring, const LDRserBase
       return false;
     }
 
-    LDRendianess endianess;
-    STD_string endianess_string=shrink(headertokens[1]);
-    endianess.LDRenum::operator = (endianess_string);
-    ODINLOG(odinlog,normalDebug) << "header/encodingtype/endianess_string=" << header << "/" << encodingtype << "/" << endianess_string << STD_endl;
+    LDRendianness endianness;
+    STD_string endianness_string=shrink(headertokens[1]);
+    endianness.LDRenum::operator = (endianness_string);
+    ODINLOG(odinlog,normalDebug) << "header/encodingtype/endianness_string=" << header << "/" << encodingtype << "/" << endianness_string << STD_endl;
 
     STD_string typestring=shrink(headertokens[2]);
     if(typestring!=basetype.get_typeInfo()) {
@@ -376,7 +376,7 @@ bool LDRarray<A,J>::parsevalstring(const STD_string& parstring, const LDRserBase
       bool encresult;
       if( (encresult=b64.decode(encoded_string,data,nbytes)) ) {
 
-        if(int(endianess)!=int(little_endian_byte_order())) {
+        if(int(endianness)!=int(little_endian_byte_order())) {
           ODINLOG(odinlog,normalDebug) << "swapping data" << STD_endl;
           swabdata(data,elsize,lnn);
         }
