@@ -565,7 +565,8 @@ STD_map<STD_string,STD_string> LDRblock::get_cmdline_options() const {
       if(defval!="" || alt.size()) {
         descr+=" (";
         if(alt.size()) descr+="options="+tokenstring(alt,0)+", ";
-        if(defval!="") descr+="default="+defval+unit;
+        if(defval!="") descr+="default="+defval;
+//        if(defval!="") descr+="default="+defval+unit;
         descr+=")";
       }
 
