@@ -1,3 +1,4 @@
+#include "odinpara.h"
 #include "ldrtypes.h"
 #include "ldrblock.h" // for UnitTest
 #include <tjutils/tjtest.h>
@@ -240,7 +241,7 @@ LDRenum::operator STD_string () const {
   else return "";
 }
 
-static STD_string notext("none");
+static STD_string notext(ODIN_NONE_STR);
   
 const STD_string& LDRenum::get_item(unsigned int index) const {
   STD_map<int,STD_string>::const_iterator it=entries.begin();
