@@ -2,7 +2,7 @@
                           odinpara.h  -  description
                              -------------------
     begin                : Tue Jun 28 2005
-    copyright            : (C) 2000-2019 by Thies H. Jochimsen
+    copyright            : (C) 2000-2021 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -27,6 +27,9 @@
   * @{
   */
 
+#define ODIN_NONE_STR "none"
+#define ODIN_UNKNOWN_STR "Unknown"
+
 /**
   * @ingroup odinpara
   * This enum is used to specify directions in the coordinate system
