@@ -282,13 +282,13 @@ int kSpaceCoord::max_parsepos;
 ////////////////////////////////////////////////////////////////////////////
 
 
-JDXkSpaceCoords::JDXkSpaceCoords() : state(coords_in_list) {
-  Log<Para> odinlog(this,"JDXkSpaceCoords()");
-  JDXkSpaceCoords::clear();
+LDRkSpaceCoords::LDRkSpaceCoords() : state(coords_in_list) {
+  Log<Para> odinlog(this,"LDRkSpaceCoords()");
+  LDRkSpaceCoords::clear();
 }
 
 
-void JDXkSpaceCoords::clear() {
+void LDRkSpaceCoords::clear() {
   Log<Para> odinlog(this,"clear");
   if(state==has_vec_alloc) {
     for(unsigned int i=0; i<size(); i++) {
@@ -302,7 +302,7 @@ void JDXkSpaceCoords::clear() {
 }
 
 
-JDXkSpaceCoords& JDXkSpaceCoords::append_coord(const kSpaceCoord& coord) {
+LDRkSpaceCoords& LDRkSpaceCoords::append_coord(const kSpaceCoord& coord) {
   state=coords_in_list;
   coord.number=coordlist.size();
   coordlist.push_back(coord);
@@ -310,7 +310,7 @@ JDXkSpaceCoords& JDXkSpaceCoords::append_coord(const kSpaceCoord& coord) {
 }
 
 
-void JDXkSpaceCoords::create_vec_cache() const {
+void LDRkSpaceCoords::create_vec_cache() const {
   if(state==has_vec_cache || state==has_vec_alloc) return;
 
   for(int j=0; j<n_recoIndexDims; j++) numof_cache[j]=1;
@@ -329,7 +329,7 @@ void JDXkSpaceCoords::create_vec_cache() const {
 }
 
 
-bool JDXkSpaceCoords::parsevalstring (const STD_string& parstring) {
+bool LDRkSpaceCoords::parsevalstring(const STD_string& parstring, const LDRserBase*) {
   Log<Para> odinlog(this,"parsevalstring");
   ODINLOG(odinlog,normalDebug) << "tokenizing ..." << STD_endl;
   svector toks(tokens(parstring));
@@ -353,7 +353,7 @@ bool JDXkSpaceCoords::parsevalstring (const STD_string& parstring) {
 }
 
 
-STD_string JDXkSpaceCoords::printvalstring() const {
+STD_string LDRkSpaceCoords::printvalstring(const LDRserBase*) const {
   create_vec_cache();
   STD_string result(kSpaceCoord::print_header(numof_cache)+"\n");
   for(unsigned int i=0; i<size(); i++) {
@@ -364,7 +364,7 @@ STD_string JDXkSpaceCoords::printvalstring() const {
 }
 
 
-STD_ostream& JDXkSpaceCoords::print2stream(STD_ostream& os) const {
+STD_ostream& LDRkSpaceCoords::print2stream(STD_ostream& os, const LDRserBase& serializer) const {
   create_vec_cache();
   os << kSpaceCoord::print_header(numof_cache) << "\n";
   unsigned int ncoords=size();
@@ -378,18 +378,18 @@ STD_ostream& JDXkSpaceCoords::print2stream(STD_ostream& os) const {
 
 //////////////////////////////////////////////////////////////////
 
-JDXrecoValList::JDXrecoValList(const STD_string& ldrlabel) {
-  Log<Para> odinlog(ldrlabel.c_str(), "JDXrecoValList(label)");
+LDRrecoValList::LDRrecoValList(const STD_string& ldrlabel) {
+  Log<Para> odinlog(ldrlabel.c_str(), "LDRrecoValList(label)");
   set_label(ldrlabel);
 }
 
-JDXrecoValList& JDXrecoValList::operator = (const JDXrecoValList& jdrvl) {
+LDRrecoValList& LDRrecoValList::operator = (const LDRrecoValList& jdrvl) {
   RecoValList::operator = (jdrvl);
-  JcampDxClass::operator = (jdrvl);
+  LDRbase::operator = (jdrvl);
   return *this;
 }
 
-JDXrecoValList& JDXrecoValList::operator = (const RecoValList& rvl) {
+LDRrecoValList& LDRrecoValList::operator = (const RecoValList& rvl) {
   STD_string label_backup(get_label());
   RecoValList::operator = (rvl);
   set_label(label_backup);
@@ -397,19 +397,19 @@ JDXrecoValList& JDXrecoValList::operator = (const RecoValList& rvl) {
 }
 
 
-bool JDXrecoValList::parsevalstring (const STD_string& parstring) {
+bool LDRrecoValList::parsevalstring (const STD_string& parstring, const LDRserBase*) {
   Log<Para> odinlog(this,"parsevalstring");
   STD_string sting4vallist(rmblock(parstring,"(",")",true,true));
   return ValList<int>::parsevallist(sting4vallist);
 }
 
 
-STD_string JDXrecoValList::printvalstring() const {
+STD_string LDRrecoValList::printvalstring(const LDRserBase*) const {
   return "("+itos(size())+")\n"+tokenstring(tokens(ValList<int>::printvallist())); // nice formatting
 }
 
 
-STD_ostream& JDXrecoValList::print2stream(STD_ostream& os) const {
+STD_ostream& LDRrecoValList::print2stream(STD_ostream& os, const LDRserBase& serializer) const {
   os << "(" << itos(size()) << ")\n";
   ValList<int>::print2stream(os);
   return os;
@@ -423,7 +423,7 @@ void RecoPars::common_init() {
   ReadoutDstSize.resize(MAX_NUMOF_READOUT_SHAPES);
 }
 
-RecoPars::RecoPars(const STD_string& label) : JcampDxBlock(label) {
+RecoPars::RecoPars(const STD_string& label) : LDRblock(label) {
   Log<Para> odinlog(this,"RecoPars(label)");
 
   common_init();
@@ -444,10 +444,10 @@ RecoPars::RecoPars(const RecoPars& sr) {
 
 
 RecoPars& RecoPars::operator = (const RecoPars& sr) {
-  JcampDxBlock::operator = (sr);
+  LDRblock::operator = (sr);
   append_all_members();
 
-  // copy only visible members of JcampDxBlock
+  // copy only visible members of LDRblock
   copy_ldr_vals(sr);
   return (*this);
 }
@@ -469,7 +469,7 @@ int RecoPars::append_readout_shape(const fvector& shape, unsigned int dstsize) {
       ReadoutDstSize[i]=dstsize;
       return i;
     }
-    if((const STD_vector<float>&)ReadoutShape[i]==(const STD_vector<float>&)shape && ReadoutDstSize[i]==dstsize) { // cast is required for VxWorks
+    if((const STD_vector<float>&)ReadoutShape[i]==(const STD_vector<float>&)shape && ReadoutDstSize[i]==int(dstsize)) { // cast is required for VxWorks
       return i;
     }
   }
@@ -642,7 +642,7 @@ void RecoPars::append_all_members() {
 //////////////////////////////////////////////////////////////////
 
 
-CoilSensitivity::CoilSensitivity(const STD_string& label) : JcampDxBlock(label) {
+CoilSensitivity::CoilSensitivity(const STD_string& label) : LDRblock(label) {
   append_all_members();
 }
 
@@ -651,10 +651,10 @@ CoilSensitivity::CoilSensitivity(const CoilSensitivity& cs) {
 }
 
 CoilSensitivity& CoilSensitivity::operator = (const CoilSensitivity& cs) {
-  JcampDxBlock::operator = (cs);
+  LDRblock::operator = (cs);
   append_all_members();
 
-  // copy only visible members of JcampDxBlock
+  // copy only visible members of LDRblock
   copy_ldr_vals(cs);
   return *this;
 }
