@@ -6,7 +6,7 @@ SeqPars::SeqPars(const STD_string& label) : LDRblock(label) {
   ExpDuration.set_description("The overall duration of the sequence");
   ExpDuration.set_unit("min");
 
-  Sequence="Unknown";
+  Sequence=ODIN_UNKNOWN_STR;
   Sequence.set_parmode(hidden);
   Sequence.set_description("The MR sequence used");
 
