@@ -43,10 +43,10 @@ Study::Study(const STD_string& label) : LDRblock(label) {
   ScanDate.set_cmdline_option("date").set_unit("yyyymmdd").set_description("Date of scan");
   ScanTime.set_cmdline_option("time").set_unit("hhmmss").set_description("Time of scan");
 
-  PatientId="Unknown";
+  PatientId=ODIN_UNKNOWN_STR;
   PatientId.set_cmdline_option("pid").set_description("Unique patient identifier");
 
-  PatientName="Unknown";
+  PatientName=ODIN_UNKNOWN_STR;
   PatientName.set_cmdline_option("pname").set_description("Full patient name");
 
   PatientBirthDate=STD_string(ODIN_DATE_LENGTH,'0');
@@ -63,13 +63,13 @@ Study::Study(const STD_string& label) : LDRblock(label) {
   PatientSize=2000.0;
   PatientSize.set_cmdline_option("psize").set_unit(ODIN_SPAT_UNIT).set_description("Patients size/height");
 
-  Description="Unknown";
+  Description=ODIN_UNKNOWN_STR;
   Description.set_cmdline_option("stud").set_description("Study Description");
 
-  ScientistName="Unknown";
+  ScientistName=ODIN_UNKNOWN_STR;
   ScientistName.set_cmdline_option("scient").set_description("Scientist Name");
 
-  SeriesDescription="Unknown";
+  SeriesDescription=ODIN_UNKNOWN_STR;
   SeriesDescription.set_cmdline_option("serd").set_description("Series Description");
 
   SeriesNumber=1;
