@@ -211,10 +211,10 @@ System::System(const STD_string& object_label) : LDRblock(object_label) {
   reference_gain=20.0;
   reference_gain.set_unit("dB").set_description("RF reference gain");
 
-  transmit_coil_name="Unknown";
+  transmit_coil_name=ODIN_UNKNOWN_STR;
   transmit_coil_name.set_cmdline_option("tcname").set_description("Name of transmit coil");
 
-  receive_coil_name="Unknown";
+  receive_coil_name=ODIN_UNKNOWN_STR;
   receive_coil_name.set_cmdline_option("rcname").set_description("Name of receive coil");
 
   inter_grad_delay=0.0;
