@@ -433,8 +433,15 @@ LDRwidget::~LDRwidget(){
   if(grid) delete grid;
 }
 
+
 STD_string LDRwidget::get_label() const {return val.get_label();}
 
+
+int LDRwidget::get_current_z() const {
+  if(floatArrwidget2) return floatArrwidget2->get_current_z();
+  return -1;
+}
+
 void LDRwidget::set_widget(QWidget *widget, GuiGridLayout::Alignment alignment, bool override_enabled) {
   Log<OdinQt> odinlog(&val,"set_widget");
 
