@@ -680,7 +680,7 @@ GuiApplication::GuiApplication(int argc, char *argv[]) {
 
 
   // initialise debug handler, do not trigger error about components already registered because this might be run within paravision
-  if(LogBase::set_log_levels(argc,argv,false)) exit(0);
+  if(LogBase::set_log_levels(argc,argv,false)) return;
 
   Log<OdinQt> odinlog("GuiApplication","GuiApplication");
   ODINLOG(odinlog,normalDebug) << "argc/argv=" << argc << "/" << argv << STD_endl;
@@ -712,8 +712,10 @@ GuiApplication::GuiApplication(int argc, char *argv[]) {
 
 
 int GuiApplication::start(QWidget* mainwidget) {
+  Log<OdinQt> odinlog("GuiApplication","start");
 #ifndef QT_VERSION_POST3
   qa->setMainWidget(mainwidget);
+  ODINLOG(odinlog,normalDebug) << "setMainWidget done" << STD_endl;
 #endif
 //  mainwidget->show();
   return qa->exec();
