@@ -15,20 +15,21 @@ RecoBlackBoard::~RecoBlackBoard() {
 void RecoBlackBoard::post(const STD_string& label, const RecoData& data) {
   Log<Reco> odinlog("RecoBlackBoard","post");
 
-  mutex.lock();
-
+  postedmutex.lock();
   CoordDataMap& cdmap=posted[label];
-
   if(cdmap.find(data.coord())!=cdmap.end()) {
     ODINLOG(odinlog,warningLog) << label << "(" << data.coord().print() << ") posted already, will overwrite it" << STD_endl;
   }
   cdmap[data.coord()]=data; // deep copy
+  postedmutex.unlock();
 
   ODINLOG(odinlog,normalDebug) << "Posted " << label << "(" << data.coord().print() << ")" << STD_endl;
 
+
   // Notify other waiting threads via event
   STD_list<Event*> eventlist;
 
+  eventmutex.lock();
   LabelEventMap::iterator lit=eventmap.find(label);
   if(lit!=eventmap.end()) {
     CoordEventMap& ccm=lit->second;
@@ -36,10 +37,10 @@ void RecoBlackBoard::post(const STD_string& label, const RecoData& data) {
       if(cit->first==data.coord()) eventlist.push_back(cit->second); // Find ALL coords whicht match the data
     }
   }
-  mutex.unlock();
+  eventmutex.unlock();
 
   if(eventlist.size()) {
-    ODINLOG(odinlog,normalDebug) << "Signaling " << eventlist.size() << " threads waiting for " << label << "(" << data.coord().print() << ")" << STD_endl;
+    ODINLOG(odinlog,normalDebug) << "Signaling " << eventlist.size() << " events waiting for " << label << "(" << data.coord().print() << ")" << STD_endl;
     for(STD_list<Event*>::const_iterator it=eventlist.begin(); it!=eventlist.end(); ++it) {
       (*it)->signal();
     }
@@ -50,6 +51,8 @@ void RecoBlackBoard::post(const STD_string& label, const RecoData& data) {
 bool RecoBlackBoard::get_data(const STD_string& label, RecoData& data) {
   Log<Reco> odinlog("RecoBlackBoard","get_data");
 
+  MutexLock lock(postedmutex);
+
   LabelDataMap::const_iterator lit=posted.find(label);
   if(lit==posted.end()) return false;
 
@@ -69,14 +72,14 @@ bool RecoBlackBoard::inquire(const STD_string& label, RecoData& data, bool block
 
   ODINLOG(odinlog,normalDebug) << "Requested " << label << "(" << data.coord().print() << ")" << STD_endl;
 
-  mutex.lock();
 
-  if(get_data(label,data)) {mutex.unlock(); return true;} // We're done here
+  if(get_data(label,data)) {return true;} // We're done here
 
-  if(!blocking) {mutex.unlock(); return false;} // We're done here
+  if(!blocking) {return false;} // We're done here
 
   Event* event=0;
 
+  eventmutex.lock();
   CoordEventMap& ccm=eventmap[label];
   CoordEventMap::iterator cit=ccm.find(data.coord());
   if(cit==ccm.end()) {
@@ -84,17 +87,16 @@ bool RecoBlackBoard::inquire(const STD_string& label, RecoData& data, bool block
     event=new Event;
     ccm[data.coord()]=event;
   } else {
+    ODINLOG(odinlog,normalDebug) <<  "Using existing event for " << label << "(" << data.coord().print() << ")" << STD_endl;
     event=cit->second; // Already there
   }
-  mutex.unlock();
+  eventmutex.unlock();
 
-  if(event) event->wait();
+  if(event) event->wait(); // Block
 
   ODINLOG(odinlog,normalDebug) << "received signal for " << label << "(" << data.coord().print() << ")" << STD_endl;
 
-  mutex.lock();
   bool result=get_data(label,data); // Try again
-  mutex.unlock();
 
   if(!result) {
     ODINLOG(odinlog,warningLog) << "Data not available after wait: " << label << "(" << data.coord().print() << ")" << STD_endl;
@@ -104,6 +106,15 @@ bool RecoBlackBoard::inquire(const STD_string& label, RecoData& data, bool block
 }
 
 
+void RecoBlackBoard::release_waiting_threads() {
+  MutexLock lock(eventmutex);
+  for(LabelEventMap::const_iterator lit=eventmap.begin(); lit!=eventmap.end(); ++lit) {
+    for(CoordEventMap::const_iterator cit=lit->second.begin(); cit!=lit->second.end(); ++cit) {
+      cit->second->signal();
+    }
+  }
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////
 
 void RecoPost::init() {
