@@ -222,7 +222,7 @@ bool RecoBladeCorr::process(RecoData& rd, RecoController& controller) {
   ComplexData<3> deapo;
   if(controller.data_announced(deapo_postlabel)) {
     RecoData rddeapo;
-    if(!controller.inquire_data(deapo_postlabel, rddeapo)) return false;
+    if(!controller.inquire_data(*this, deapo_postlabel, rddeapo)) return false;
     const ComplexData<1>& deapoline=rddeapo.data(Rank<1>());
     if(int(deapoline.size())!=inshape3d(2)) {
       ODINLOG(odinlog,errorLog) << "Size mistmatch" << STD_endl;
@@ -414,7 +414,7 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
 
       // Calculate correlation coefficient for all blades
       for (unsigned int iblade = 0; iblade < nblades; iblade++) {
-        correlationResult cr = correlation(bladesmean,bladesgrid(iblade,iphase3d,all,all));
+        correlationResult cr = correlation<float,2>(bladesmean,bladesgrid(iblade,iphase3d,all,all));
         corrweights(iblade) += cr.r;
       }
     }
