@@ -23,10 +23,10 @@ bool BladeGrid::init(const TinyVector<int,3>& inshape, const TinyVector<float,3>
   // prepare filtermask
   TinyVector<int,2> inshape2d(inshape(1),inshape(2));
   filtermask_center.resize(inshape2d);
-  filtermask_center = 0.0;
+  filtermask_center = STD_complex(0.0);
 
   if (filterkernel.get_function_name() == "NoFilter") { // NoFilter means entire blade
-    filtermask_center = 1.0;
+    filtermask_center = STD_complex(1.0);
   } else {
     TinyVector<float,2> bounds(inshape2d);
     bounds(0) = centshape(1);
@@ -116,7 +116,7 @@ ComplexData<4> BladeGrid::operator () (const ComplexData<4>& src, const dvector&
     for (int islice = 0; islice < inshape3d(0); islice++) { 
       ComplexData<2> image(dstshape);
       ComplexData<2> blade(inshape2d);
-      blade = src(iblade,islice,all,all) * filtermask_center;
+      blade(all,all) = src(iblade,islice,all,all) * filtermask_center;
       image = gridder(blade);
 
       images(iblade,islice,all,all) = image;
