@@ -195,7 +195,7 @@ bool RecoController::inquire_data(const RecoStep& caller, const STD_string& labe
 
   if(!status) {
     blackboard.release_waiting_threads();
-    return false; // Return immediately if an error occured, i.e. do not wait for any data in this case
+    return false; // Return immediately if an error occurred, i.e. do not wait for any data in this case
   }
 
   ODINLOG(odinlog,normalDebug) << "Requested " << label << "(" << data.coord().print() << ") by " << caller.label() << STD_endl;
@@ -810,7 +810,7 @@ bool RecoController::create_selection_map(const STD_string& selstr, STD_map<reco
         }
         selmap[recoDim(dim)]=sel;
       } else {
-        ODINLOG(odinlog,errorLog) << "Unknwon selection dimension " << toks[0] << STD_endl;
+        ODINLOG(odinlog,errorLog) << "Unknown selection dimension " << toks[0] << STD_endl;
         return false;
       }
     } else {
@@ -897,7 +897,7 @@ bool RecoController::init(RecoReaderInterface* reader, LDRblock& opts, int argc,
         initcoord.index[dim].set_mode(RecoIndex::single);
         selmap[recoDim(dim)]=sel;
       } else {
-        ODINLOG(odinlog,errorLog) << "Unknwon selection dimension " << toks[0] << STD_endl;
+        ODINLOG(odinlog,errorLog) << "Unknown selection dimension " << toks[0] << STD_endl;
         return false;
       }
     } else {
@@ -991,7 +991,7 @@ bool RecoController::dump_raw() const {
 bool RecoController::feed_pipeline() {
   Log<Reco> odinlog("RecoController","feed_pipeline");
 
-  if(!status) return false; // Return immediately if an error occured
+  if(!status) return false; // Return immediately if an error occurred
 
   if(!input) return false;
 
