@@ -16,7 +16,7 @@ bool RecoDTI::process(RecoData& rd, RecoController& controller) {
 
   dvector bvals=controller.dim_values(dti);
 
-  JDXtriple bvector(bvals[3*idti], bvals[3*idti+1], bvals[3*idti+2], "Diffusion_bVector");
+  LDRtriple bvector(bvals[3*idti], bvals[3*idti+1], bvals[3*idti+2], "Diffusion_bVector");
   bvector*=1000.0; // in s/mm^2
 
   prot.study.set_Series("b"+replaceStr(bvector.printbody()," ","_"),number);
