@@ -181,7 +181,7 @@ bool RecoFieldMapUser::get_fmap(Data<float,3>& fieldmap, const TinyVector<int,3>
 
     RecoData rdfieldmap(fmapcoord);
     rdfieldmap.coord().index[cycle] = 0; // reset to 0 to only get initial (not rotated) field map
-    if(!controller.inquire_data(posted_fmap_str, rdfieldmap)) return false;
+    if(!controller.inquire_data(*this, posted_fmap_str, rdfieldmap)) return false;
 
     float os_fmap = rdfieldmap.coord().overSamplingFactor;
     float os_user = fmapcoord.overSamplingFactor;
