@@ -166,7 +166,7 @@ bool RecoPhaseCorr::process(RecoData& rd, RecoController& controller) {
   one_echo_phasemap.coord().index[echo]=rd.coord().echopos;
   one_echo_phasemap.coord().index[epi]=rd.coord().echotrain;
 
-  if(!controller.inquire_data(posted_phasemap_label, one_echo_phasemap)) return false;
+  if(!controller.inquire_data(*this, posted_phasemap_label, one_echo_phasemap)) return false;
 
   ComplexData<1>& pmap=one_echo_phasemap.data(Rank<1>());
 
