@@ -129,9 +129,9 @@ bool RecoReaderISMRMRD::init(const STD_string& input_filename) {
   ISMRMRD::EncodingSpace& encspace=enc.encodedSpace;
 
 
-  STD_string patid="Unknown";
+  STD_string patid=ODIN_UNKNOWN_STR;
   if(xmlsubj.patientID) patid=xmlsubj.patientID.get();
-  STD_string patname="Unknown";
+  STD_string patname=ODIN_UNKNOWN_STR;
   if(xmlsubj.patientName) patname=xmlsubj.patientName.get();
   STD_string patbirth="00000000";
   if(xmlsubj.patientBirthdate) patbirth=xmlsubj.patientBirthdate.get();
