@@ -154,9 +154,9 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
     rawdata_filename=fifoFile;
   }
 
-  // get format and endianess of raw data
+  // get format and endianness of raw data
   dataformat=recoInfo.get_DataFormat();
-  if(dataformat=="long") dataformat="s32bit"; // for backwards compatability
+  if(dataformat=="long") dataformat="s32bit"; // for backwards compatibility
   rawtypesize=TypeTraits::typesize(dataformat);
   if(!rawtypesize) {
     ODINLOG(odinlog,errorLog) << "Unrecognized dataformat >" << dataformat << "<" << STD_endl;
@@ -224,7 +224,7 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
   // load protocol
   STD_string protfile=scandir+SEPARATOR_STR+"protocol";
   if(filesize(protfile.c_str())>0) {
-    prot_cache.load(protfile); // Backwards compatability
+    prot_cache.load(protfile); // Backwards compatibility
     ODINLOG(odinlog,infoLog) << "Loading protocol from " << protfile << STD_endl;
     if(prot_cache.seqpars.get_EchoTime()<=0.0) {
       LDRfloatArr tes;
