@@ -656,7 +656,7 @@ OdinPulse& OdinPulse::generate() {
 
   // precalculations for Nyquist check
   float max_spatial_extension=0.5*data->field_of_excitation;  // Assume single point as the excitation shape, so that, in contrast to a shape that fills the whole FOX, aliases would appear at (+/- FOX).  Therefore, we can effectively use half the FOX without aliasing.
-  max_spatial_extension*=sqrt(mode); // extend to diagonal direction square-shaped alias-free FOX
+  max_spatial_extension*=sqrt(float(int(mode))); // extend to diagonal direction square-shaped alias-free FOX
   max_spatial_extension+=data->shape.get_shape_info().spatial_extent; // If shape is not single point, add the total extent of the shape. Otherwise it aliases into the FOX.
   if(mode==oneDeeMode) {
     dkmax=max_kspace_step(data->Gs, gamma, data->Tp_1pulse, data->G0);
