@@ -7,6 +7,10 @@ void SeqGradPhaseEnc::init_encoding(unsigned int nsteps, encodingScheme scheme,
   if(partial_fourier>1.0) partial_fourier=1.0;
   unsigned int startindex=(unsigned int)(partial_fourier*0.5*nsteps+0.5);
 
+  if( partial_fourier && (scheme==centerOutEncoding || scheme==centerInEncoding ) ) {
+    ODINLOG(odinlog,warningLog) << "center in/out encoding and partial Fourier: Not implemented" << STD_endl;
+  }
+
   // some plausibility checks
   if(reduction>nsteps) reduction=nsteps;  // / order is important
   if(reduction<1) reduction=1;            // \ here because nsteps might be 0
