@@ -28,8 +28,10 @@ float SeqGradWave::get_integral(double tmin, double tmax) const {
   double dur=get_gradduration();
   ODINLOG(odinlog,normalDebug) << "dur=" << dur << STD_endl;
 
-  if(tmin<0.0) tmin=0.0; if(tmin>dur) tmin=dur;
-  if(tmax<0.0) tmax=0.0; if(tmax>dur) tmax=dur;
+  if(tmin<0.0) tmin=0.0;
+  if(tmin>dur) tmin=dur;
+  if(tmax<0.0) tmax=0.0;
+  if(tmax>dur) tmax=dur;
   ODINLOG(odinlog,normalDebug) << "dur/tmin/tmax=" << dur << "/" << tmin << "/" << tmax << STD_endl;
 
   double len=double(wave.length());
