@@ -57,13 +57,13 @@ class CatchSegFaultContext : public StaticHandler<CatchSegFaultContext> {
     Log<Seq> odinlog(label->c_str(),"~CatchSegFaultContext");
     sa.sa_handler=SIG_DFL;
     sigaction(SIGSEGV,&sa,0);
-    segfault_occured=false;
+    segfault_occurred=false;
   }
 
   bool segfault() volatile {
     Log<Seq> odinlog(label->c_str(),"segfault");
-    bool result=segfault_occured;
-    segfault_occured=false;
+    bool result=segfault_occurred;
+    segfault_occurred=false;
     return result;
   }
 
@@ -73,7 +73,7 @@ class CatchSegFaultContext : public StaticHandler<CatchSegFaultContext> {
       (*lastmsg)="Segmentation fault in " + (*label);
       ODINLOG(odinlog,errorLog) << (*lastmsg) << STD_endl;
     }
-    segfault_occured=true;
+    segfault_occurred=true;
     longjmp(CatchSegFaultContext::segfault_cont_pos, 0);
   }
 
@@ -108,14 +108,14 @@ class CatchSegFaultContext : public StaticHandler<CatchSegFaultContext> {
 
   static STD_string* label;
   struct sigaction sa;
-  static bool segfault_occured;
+  static bool segfault_occurred;
   static jmp_buf segfault_cont_pos;
   static STD_string* lastmsg;
 
 };
 
 STD_string*    CatchSegFaultContext::label=0;
-bool           CatchSegFaultContext::segfault_occured = false;
+bool           CatchSegFaultContext::segfault_occurred = false;
 jmp_buf        CatchSegFaultContext::segfault_cont_pos;
 STD_string*    CatchSegFaultContext::lastmsg=0;
 EMPTY_TEMPL_LIST bool StaticHandler<CatchSegFaultContext>::staticdone=false;
