@@ -104,8 +104,12 @@ bool SeqPuls::prep() {
 
   if(!SeqFreqChan::prep()) return false;
 
-  if(wave.length()==0) ODINLOG(odinlog,warningLog) << "Empty waveform" << STD_endl;
-  if(wave.maxabs()==STD_complex(0,0)) ODINLOG(odinlog,warningLog) << "Zero filled waveform" << STD_endl;
+  if(wave.length()==0) {
+    ODINLOG(odinlog,warningLog) << "Empty waveform" << STD_endl;
+  }
+  if(wave.maxabs()==STD_complex(0,0)) {
+    ODINLOG(odinlog,warningLog) << "Zero filled waveform" << STD_endl;
+  }
 
   ODINLOG(odinlog,normalDebug) << "B1max_mT=" << B1max_mT << STD_endl;
 
