@@ -90,7 +90,7 @@ void SeqVecIter::query(queryContext& context) const {
 }
 
 
-RecoValList SeqVecIter::get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const {
+RecoValList SeqVecIter::get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const {
   Log<Seq> odinlog(this,"get_recovallist");
   RecoValList dummy;
 
