@@ -31,6 +31,15 @@ bool  SeqTriggerStandAlone::prep_snaptrigger(const STD_string& snapshot_fname) {
   return true;
 }
 
+bool  SeqTriggerStandAlone::prep_resettrigger() {
+  trigg_marker.label="Magnetization Reset";
+  trigg_marker.marklabel=markLabel[reset_marker];
+  trigg_marker.marker=reset_marker;
+  trigg_marker.marker_x=0.0;
+  if(dump2console) STD_cout << trigg_marker << STD_endl;
+  return true;
+}
+
 void SeqTriggerStandAlone::event(eventContext& context, double startelapsed) const {
   append_curve2plot(startelapsed,&trigg_marker);
 }
