@@ -32,13 +32,13 @@ class METHOD_CLASS : public SeqMethod {
  private:
 
   // Parameters for this method:
-  JDXfloat T1Ernst;
-  JDXint   DummyCycles;
+  LDRfloat T1Ernst;
+  LDRint   DummyCycles;
 
-  JDXint NumSagSlices;
-  JDXint NumCorSlices;
-  JDXint NumAxiSlices;
-  JDXfloat PilotSliceDist;
+  LDRint NumSagSlices;
+  LDRint NumCorSlices;
+  LDRint NumAxiSlices;
+  LDRfloat PilotSliceDist;
 
   // Sequence objects for this method:
   SeqPulsar exc;
@@ -224,7 +224,7 @@ void METHOD_CLASS::method_seq_init() {
 
   float os_factor=2.0; // avoid cut-off in read direction for off-center FOV
 
-  // This is the gradient-recalled echo kernel of the sequence.
+  // This is the gradient-recalled echo kernel (2D mode) of the sequence.
   // Calculations of read/phase gradient strengts and durations are
   // performed by this module itself so we just have to pass in the size and FOV
   // in each direction. This module has a tight timing scheme so that short TE is possible.
