@@ -17,6 +17,7 @@ class METHOD_CLASS : public SeqMethod {
   SeqGradPhaseEnc pe3d1,pe3d2;
 
   SeqGradConstPulse spoiler;
+  SeqGradConstPulse crusher;
 
   SeqDelay echopad;
   SeqDelay excpad;
@@ -46,13 +47,13 @@ class METHOD_CLASS : public SeqMethod {
 
 
 
-  JDXenum   PhaseEncoding;
-  JDXint    NumOfSegments;
-  JDXdouble PulseDur;
-  JDXdouble refocFlipAngle;
-  JDXdouble SpoilerStrength;
-  JDXdouble SpoilerDuration;
-  JDXbool   TemplScan;
+  LDRenum   PhaseEncoding;
+  LDRint    NumOfSegments;
+  LDRdouble PulseDur;
+  LDRdouble refocFlipAngle;
+  LDRdouble SpoilerStrength;
+  LDRbool   TemplScan;
+  LDRdouble RefocRate;
 
 
  public:
@@ -84,20 +85,21 @@ class METHOD_CLASS : public SeqMethod {
     SpoilerStrength=50.0;
     SpoilerStrength.set_unit("%").set_description("Spoiler-gradient strength in percent of max gradient amplitude");
 
-    SpoilerDuration=1.0;
-    SpoilerDuration.set_unit(ODIN_TIME_UNIT).set_description("Spoiler-gradient duration");
-
     TemplScan=true;
     TemplScan.set_description("Acquire and use template scan for phase correction");
 
+    RefocRate.set_unit(ODIN_TIME_UNIT).set_description("Spacing between refocusing pulses");
+
+
 
     // alternative default settings for sequence test
     if(get_current_testcase()==1) {
       geometryInfo->set_Mode(voxel_3d);
+      PhaseEncoding=linearEncoding;
+      commonPars->set_PartialFourier(0.8);
       PulseDur=6.0;
       refocFlipAngle=120.0;
       SpoilerStrength=30.0;
-      SpoilerDuration=2.0;
     }
     if(get_current_testcase()==2) {
       commonPars->set_ReductionFactor(3);
@@ -109,10 +111,10 @@ class METHOD_CLASS : public SeqMethod {
     append_parameter(NumOfSegments,"NumOfSegments");
     append_parameter(PulseDur,"PulseDur");
     append_parameter(TemplScan,"TemplScan");
-
     append_parameter(refocFlipAngle,"refocFlipAngle");
     append_parameter(SpoilerStrength,"SpoilerStrength");
-    append_parameter(SpoilerDuration,"SpoilerDuration");
+    append_parameter(RefocRate,"RefocRate",noedit);
+
 
   }
 
@@ -148,9 +150,9 @@ void method_seq_init(){
 
   // Refocusing Pulse
   refoc=SeqPulsarSinc("refoc",slicethick,false,PulseDur,refocFlipAngle,spatres,256);
-  refoc.set_phase(90.0);
   if(geometryInfo->get_Mode()==slicepack) refoc.set_freqlist  (gamma * refoc.get_strength() / (2.0*PII) *  geometryInfo->get_sliceOffsetVector()  );
   if(geometryInfo->get_Mode()==voxel_3d)  refoc.set_freqoffset(gamma * refoc.get_strength() / (2.0*PII) *  geometryInfo->get_offset(sliceDirection)  );
+  refoc.set_phase(90.0);
   refoc.set_pulse_type(refocusing);
 
 
@@ -169,7 +171,7 @@ void method_seq_init(){
 
 
   //////////////// Phase Encoding: //////////////////////////
-
+  
   pe1=SeqGradPhaseEnc("pe1",commonPars->get_MatrixSize(phaseDirection),geometryInfo->get_FOV(phaseDirection),
                   phaseDirection,0.25*systemInfo->get_max_grad(),
                   encodingScheme(int(PhaseEncoding)),interleavedSegmented,NumOfSegments,
@@ -210,12 +212,15 @@ void method_seq_init(){
 
 
 
-  //////////////// Spoiler: //////////////////////////////
+  //////////////// Spoiler/Crusher: //////////////////////////////
 
-  float spoiler_strength_phys=(double)SpoilerStrength/100.0*systemInfo->get_max_grad();
+  float spoiler_strength=(double)SpoilerStrength/100.0*systemInfo->get_max_grad();
+  float spoiler_integral=2.5*fabs(readdeph.get_gradintegral().sum());
+  float spoiler_dur=secureDivision(spoiler_integral,spoiler_strength);
 
-  spoiler=SeqGradConstPulse("spoiler",phaseDirection,spoiler_strength_phys,SpoilerDuration);
+  spoiler=SeqGradConstPulse("spoiler",phaseDirection,spoiler_strength,spoiler_dur);
 
+  crusher=SeqGradConstPulse("crusher",readDirection,spoiler_strength,2.0*spoiler_dur);
 
   //////////////// several padding delays ////////////////////
 
@@ -274,8 +279,8 @@ void method_seq_init(){
   echopart_templ=      refoc + spoiler + echopad + pe1delay      + acqread_templ  +  pe2delay      + echopad + spoiler;
   echopart      =      refoc + spoiler + echopad + pe1part       + acqread        +  pe2part       + echopad + spoiler;
 
-  readout_templ = exc + postexc + excpad + echoloop(echopart_templ)[echoindex];
-  readout       = exc + postexc + excpad + echoloop(echopart)      [pe1][pe2][echoindex];
+  readout_templ = exc + postexc + excpad + echoloop(echopart_templ)[echoindex] + crusher;
+  readout       = exc + postexc + excpad + echoloop(echopart)      [pe1][pe2][echoindex] + crusher;
 
 
   if(geometryInfo->get_Mode()==voxel_3d) {
@@ -336,7 +341,39 @@ void method_seq_init(){
     ODINLOG(odinlog,significantDebug) << "echopad=" << echopad.get_duration() << STD_endl;
     ODINLOG(odinlog,significantDebug) << "excpad=" << excpad.get_duration() << STD_endl;
 
-    commonPars->set_EchoTime(echopart.get_duration(),noedit);
+
+    RefocRate=echopart.get_duration();
+
+
+    // Find echo with minimum phase encoding for TE calculation
+    iarray indexmat=((SeqVector)pe1).get_index_matrix();
+    ODINLOG(odinlog,significantDebug) << "indexmat=" << indexmat << STD_endl;
+    fvector trims=pe1.get_trims();
+    ODINLOG(odinlog,significantDebug) << "trims=" << trims << STD_endl;
+    float mintrim=-1.0;
+    unsigned int minreorder=0;
+    unsigned int miniter=0;
+    for(unsigned int ireorder=0; ireorder<indexmat.size(0); ireorder++) {
+      for(unsigned int iter=0; iter<indexmat.size(1); iter++) {
+        unsigned int itrim=indexmat(ireorder,iter);
+        float trimabsval=fabs(trims[itrim]);
+        bool ismin=false;
+        if(!ireorder && !iter) { // 1st value
+          ismin=true;
+        } else {
+          if(trimabsval<mintrim) ismin=true;
+        }
+        if(ismin) {
+          mintrim=trimabsval;
+          minreorder=ireorder;
+          miniter=iter;
+        }
+        ODINLOG(odinlog,significantDebug) << "(ireorder/iter/itrim) trimabsval=" << "(" << ireorder << "/" << iter << "/" << itrim<< ") " <<  trimabsval << STD_endl;
+      }
+    }
+    ODINLOG(odinlog,significantDebug) << "minreorder/miniter/mintrim=" << minreorder << "/" << miniter << "/" << mintrim << STD_endl;
+    commonPars->set_EchoTime((miniter+1)*RefocRate,noedit);
+
 
     // calculate relaxdelay to get the desired repetition time
     float scandur=readout.get_duration()*float(geometryInfo->get_nSlices());
