@@ -13,7 +13,7 @@ void tjstd_ostream::buff_int(int i)     {append2buff(itos(i));}
 tjstd_ofstream::tjstd_ofstream(const char* filename) : file_ptr(0) {
 #ifndef NO_FILEHANDLING
   if(STD_string(filename)!="") {
-    FILE* fp=FOPEN(filename, modestring(overwriteMode));
+    FILE* fp=ODIN_FOPEN(filename, modestring(overwriteMode));
     if(fp!=NULL) {
       file_ptr=(void*)fp;
     }
