@@ -17,8 +17,8 @@ void UnitTest::destroy_static() {
   delete tests;
 }
 
-UnitTest::UnitTest(const char* label) {
-  set_label(label); 
+UnitTest::UnitTest(const STD_string& testlabel) {
+  set_label(testlabel); 
   tests->push_back(this);
 }
 
