@@ -551,12 +551,18 @@ void fileunmap(int fd, void* start, LONGEST_INT nbytes, LONGEST_INT offset) {
 ///////////////////////////////////////////////
 
 STD_string tempfile() {
+  Log<TjTools> odinlog("","tempfile");
   STD_string result;
   const char* ptr=tmpnam(NULL);
-  if(ptr) result=ptr;
+  if(ptr) {
+    result=ptr;
+  } else {
+    ODINLOG(odinlog,errorLog) << "tmpnam: " << lasterr() << STD_endl;
+  }
 #ifdef USING_WIN32
   result=STD_string(getenv_nonnull("TEMP"))+SEPARATOR_STR+result;
 #endif
+  ODINLOG(odinlog,normalDebug) << "result=" << result << STD_endl;
   return result;
 }
 
@@ -703,6 +709,10 @@ const char* helpUsage() {
   return "-h, --help, -help, --version : Print help text or version information";
 }
 
+const char* configInfo() {
+  return "This program is part of " PACKAGE_STRING " with configuration " ODIN_CONFIGSTR;
+ }
+
 
 #endif
 
